@@ -1,15 +1,11 @@
-# -*- coding: utf-8 -*-
 """Test custom node separator."""
 
-import six
-
 import anytree as at
 
 from .helper import assert_raises, eq_
 
 
 class MyNode(at.Node):
-
     separator = "|"
 
 
